@@ -1,7 +1,7 @@
 /* falloc.c - The file space management routines for dbm. */
 
 /* This file is part of GDBM, the GNU data base manager.
-   Copyright (C) 1990, 1991, 1993, 1994, 2007, 2011 Free Software
+   Copyright (C) 1990, 1991, 1993, 1994, 2007, 2011, 2013 Free Software
    Foundation, Inc.
 
    GDBM is free software; you can redistribute it and/or modify
@@ -158,12 +158,12 @@ _gdbm_free (GDBM_FILE dbf, off_t file_adr, int num_bytes)
 static void
 pop_avail_block (GDBM_FILE dbf)
 {
-  int  num_bytes;		/* For use with the read system call. */
+  int rc;
   off_t file_pos;		/* For use with the lseek system call. */
   avail_elem new_el;
   avail_block *new_blk;
   int index;
-
+  
   if (dbf->header->avail.count == dbf->header->avail.size)
     {
       /* We're kind of stuck here, so we re-split the header in order to
@@ -181,10 +181,11 @@ pop_avail_block (GDBM_FILE dbf)
   if (new_blk == NULL) _gdbm_fatal(dbf, _("malloc failed"));
 
   /* Read the block. */
-  file_pos = __lseek (dbf, new_el.av_adr, L_SET);
+  file_pos = __lseek (dbf, new_el.av_adr, SEEK_SET);
   if (file_pos != new_el.av_adr)  _gdbm_fatal (dbf, _("lseek error"));
-  num_bytes = __read (dbf, new_blk, new_el.av_size);
-  if (num_bytes != new_el.av_size) _gdbm_fatal (dbf, _("read error"));
+  rc = _gdbm_full_read (dbf, new_blk, new_el.av_size);
+  if (rc)
+    _gdbm_fatal (dbf, gdbm_strerror (rc));
 
   /* Add the elements from the new block to the header. */
   index = 0;
@@ -233,14 +234,13 @@ pop_avail_block (GDBM_FILE dbf)
 static void
 push_avail_block (GDBM_FILE dbf)
 {
-  int  num_bytes;
   int  av_size;
   off_t av_adr;
   int  index;
   off_t file_pos;
   avail_block *temp;
   avail_elem  new_loc;
- 
+  int rc;
 
   /* Caclulate the size of the split block. */
   av_size = ( (dbf->header->avail.size * sizeof (avail_elem)) >> 1)
@@ -278,10 +278,11 @@ push_avail_block (GDBM_FILE dbf)
   _gdbm_free (dbf, new_loc.av_adr, new_loc.av_size);
 
   /* Update the disk. */
-  file_pos = __lseek (dbf, av_adr, L_SET);
+  file_pos = __lseek (dbf, av_adr, SEEK_SET);
   if (file_pos != av_adr) _gdbm_fatal (dbf, _("lseek error"));
-  num_bytes = __write (dbf, temp, av_size);
-  if (num_bytes != av_size) _gdbm_fatal (dbf, _("write error"));
+  rc = _gdbm_full_write (dbf, temp, av_size);
+  if (rc)
+    _gdbm_fatal (dbf, gdbm_strerror (rc));
   free (temp);
 }
 
