@@ -1,7 +1,7 @@
 /* findkey.c - The routine that finds a key entry in the file. */
 
 /* This file is part of GDBM, the GNU data base manager.
-   Copyright (C) 1990, 1991, 1993, 2007, 2011 Free Software Foundation,
+   Copyright (C) 1990, 1991, 1993, 2007, 2011, 2013 Free Software Foundation,
    Inc.
 
    GDBM is free software; you can redistribute it and/or modify
@@ -75,7 +75,8 @@ _gdbm_read_entry (GDBM_FILE dbf, int elem_loc)
    return value is the location in the current hash bucket of the KEY's
    entry.  If it is found, a pointer to the data and the key are returned
    in DPTR.  If it is not found, the value -1 is returned.  Since find
-   key computes the hash value of key, that value */
+   key computes the hash value of key, that value is returned in
+   NEW_HASH_VAL. */
 int
 _gdbm_findkey (GDBM_FILE dbf, datum key, char **dptr, int *new_hash_val)
 {
